@@ -1,9 +1,11 @@
 ## File Name: BIFIEdata2svrepdesign.R
-## File Version: 0.26
+## File Version: 0.30
 
 BIFIEdata2svrepdesign <- function(bifieobj, varnames=NULL,
         impdata.index=NULL )
 {
+    requireNamespace("mitools")
+    requireNamespace("survey")
     CALL <- match.call()
     Nimp <- bifieobj$Nimp
     weights <- bifieobj$wgt
